@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE NoImplicitPrelude #-}
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE TypeFamilies #-}
@@ -170,7 +171,7 @@ module ClassyPrelude
     ) where
 
 import qualified Prelude
-import Control.Applicative ((<**>),liftA,liftA2,liftA3)
+import Control.Applicative ((<**>),liftA,liftA2,liftA3,Alternative (..), optional)
 import Data.Functor
 import Control.Exception (assert)
 import Control.Exception.Enclosed
@@ -197,7 +198,6 @@ import Data.Containers
 import Data.Builder
 import Data.MinLen
 import Data.ByteVector
-import qualified Filesystem.Path.CurrentOS as F
 import System.IO (Handle, stdin, stdout, stderr, hClose)
 
 import Debug.Trace (trace, traceShow)
@@ -301,6 +301,12 @@ length = olength
 mapM_ :: (Monad m, MonoFoldable c) => (Element c -> m ()) -> c -> m ()
 mapM_ = omapM_
 
+traverse_ :: (Applicative f, MonoFoldable c) => (Element c -> f ()) -> c -> f ()
+traverse_ = otraverse_
+
+for_ :: (Applicative f, MonoFoldable c) => c -> (Element c -> f ()) -> f ()
+for_ = ofor_
+
 forM_ :: (Monad m, MonoFoldable c) => c -> (Element c -> m ()) -> m ()
 forM_ = oforM_
 
@@ -366,8 +372,10 @@ intersect = intersection
 unions :: (MonoFoldable c, SetContainer (Element c)) => c -> Element c
 unions = ofoldl' union Monoid.mempty
 
+#if !MIN_VERSION_mono_traversable(0, 9, 3)
 intercalate :: (Monoid (Element c), IsSequence c) => Element c -> c -> Element c
 intercalate xs xss = concat (intersperse xs xss)
+#endif
 
 asByteString :: ByteString -> ByteString
 asByteString = id
@@ -465,20 +473,19 @@ traceShowM :: (Show a, Monad m) => a -> m ()
 traceShowM = traceM . show
 
 fpToString :: FilePath -> String
-fpToString = F.encodeString
+fpToString = id
+{-# DEPRECATED fpToString "Now same as id" #-}
 
 fpFromString :: String -> FilePath
-fpFromString = F.decodeString
+fpFromString = id
+{-# DEPRECATED fpFromString "Now same as id" #-}
 
 -- | Translates a 'FilePath' to a 'Text'
 --
 -- Warns if there are non-unicode sequences in the file name
-fpToTextWarn :: MonadIO m => FilePath -> m Text
-fpToTextWarn fp = case F.toText fp of
-    Right ok -> return ok
-    Left bad -> do
-        putStrLn $ pack $ "non-unicode filepath: " ++ F.encodeString fp
-        return bad
+fpToTextWarn :: Monad m => FilePath -> m Text
+fpToTextWarn = return . pack
+{-# DEPRECATED fpToTextWarn "Use pack" #-}
 
 -- | Translates a 'FilePath' to a 'Text'
 --
@@ -489,9 +496,8 @@ fpToTextWarn fp = case F.toText fp of
 -- a filename will translate properly into a 'Text'.
 -- If you created the filename, this should be the case.
 fpToTextEx :: FilePath -> Text
-fpToTextEx fp = either (const $ error errorMsg) id $ F.toText fp
-  where
-    errorMsg = "fpToTextEx: non-unicode filepath: " ++ F.encodeString fp
+fpToTextEx = pack
+{-# DEPRECATED fpToTextEx "Use pack" #-}
 
 -- | Translates a 'FilePath' to a 'Text'
 -- This translation is not correct for a (unix) filename
@@ -502,10 +508,12 @@ fpToTextEx fp = either (const $ error errorMsg) id $ F.toText fp
 -- If you control or otherwise understand the filenames
 -- and believe them to be unicode valid consider using 'fpToTextEx' or 'fpToTextWarn'
 fpToText :: FilePath -> Text
-fpToText = either id id . F.toText
+fpToText = pack
+{-# DEPRECATED fpToText "Use pack" #-}
 
 fpFromText :: Text -> FilePath
-fpFromText = F.fromText
+fpFromText = unpack
+{-# DEPRECATED fpFromText "Use unpack" #-}
 
 -- Below is a lot of coding for classy-prelude!
 -- These functions are restricted to lists right now.
@@ -610,3 +618,27 @@ asDList = id
 applyDList :: DList a -> [a] -> [a]
 applyDList = DList.apply
 {-# INLINE applyDList #-}
+
+-- | Throw a monadic exception from a String
+--
+-- > erroM = throwM . userError
+--
+-- Since 0.12.1
+errorM :: (MonadThrow m) => String -> m a
+errorM = throwM . userError
+
+-- | Throw a monadic exception from a Text
+--
+-- > terroM = errorM . unpack
+--
+-- Since 0.12.1
+terrorM :: (MonadThrow m) => Text -> m a
+terrorM = errorM . unpack
+
+-- | Throw an error from a Text
+--
+-- > terror = error . unpack
+--
+-- Since 0.12.1
+terror :: Text -> a
+terror = error . unpack
